@@ -20,6 +20,8 @@ import os
 from contextlib import contextmanager
 
 from testlib import make_file, make_uuid, namedTemporaryDir
+from testlib import maybefail
+from testlib import recorded
 from storagefakelib import FakeLVM
 from storagefakelib import FakeStorageDomainCache
 from monkeypatch import MonkeyPatchScope
@@ -28,6 +30,7 @@ from vdsm import cmdutils
 from vdsm import commands
 from vdsm import qemuimg
 from vdsm.storage import constants as sc
+from vdsm.storage import exception as se
 from vdsm.storage import guarded
 from vdsm.storage import outOfProcess as oop
 
@@ -124,14 +127,34 @@ class FakeMetadata(dict):
         yield
 
 
+class FakeVolume(object):
+
+    def __init__(self):
+        # Test may set errors here to make method calls raise expected or
+        # unexpected errors.
+        self.errors = {}
+
+    @maybefail
+    @recorded
+    def reduce(self, size):
+        pass
+
+
 class FakeSD(object):
     def __init__(self, sd_manifest):
         self._manifest = sd_manifest
+        self.volumes = {}
 
     @property
     def manifest(self):
         return self._manifest
 
+    def produceVolume(self, img_id, vol_id):
+        key = (img_id, vol_id)
+        if key not in self.volumes:
+            raise se.VolumeDoesNotExist(vol_id)
+        return self.volumes[key]
+
     def getVersion(self):
         return self._manifest.getVersion()
 
