@@ -23,6 +23,7 @@ import os
 import sanlock
 
 from vdsm.common import exception
+from vdsm import constants
 from vdsm import qemuimg
 from vdsm.commands import grepCmd
 from vdsm.storage import constants as sc
@@ -56,6 +57,11 @@ def getDomUuidFromVolumePath(volPath):
 
 class FileVolumeManifest(volume.VolumeManifest):
 
+    # Raw volumes should be aligned to sector size, which is 512 or 4096
+    # (not supported yet). qcow2 images should be aligned to cluster size
+    # (64K default). To simplify, we use 1M alignment.
+    align_size = constants.MEGAB
+
     def __init__(self, repoPath, sdUUID, imgUUID, volUUID):
         volume.VolumeManifest.__init__(self, repoPath, sdUUID, imgUUID,
                                        volUUID)
@@ -351,6 +357,23 @@ class FileVolumeManifest(volume.VolumeManifest):
             if not self.oop.os.access(volPath, os.R_OK):
                 raise se.VolumeAccessError(volPath)
 
+    def optimal_size(self):
+        """
+        Return the optimal size of the volume.
+
+        Returns:
+            virtual size if format is RAW and current (apparent) size if
+            format is COW.
+
+        Note:
+            the volume must be prepared must be prepared when calling this
+            helper.
+        """
+        if self.getFormat() == sc.RAW_FORMAT:
+            return self.getSize() * sc.BLOCK_SIZE
+        else:
+            return self.getVolumeSize() * sc.BLOCK_SIZE
+
 
 class FileVolume(volume.Volume):
     """ Actually represents a single volume (i.e. part of virtual disk).
